Particle class abstract
- Implementers
- AnimatedPositionedParticle
- AnimatedRotationParticle
- CircleMirror
- CompositeParticle
- DemoParticle
- FadingCircle
- FadingRect
- FadingSnake
- FadingTriangle
- Firework
- FourRandomSlotParticle
- IntervalParticle
- ListTileDemoParticle
- PoppingCircle
- PositionedParticle
- Rectangle2DemoParticle
- Rectangle3DemoParticle
- RectangleDemoParticle
- RectangleMirror
- RotationParticle
Constructors
- Particle()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
paint(
Canvas canvas, Size size, double progress, int seed) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited