RectangleMirror class

Mirrors a given particle around a circle.

When using the default constructor you specify one Particle, this particle is going to be used on its own, this implies that all mirrored particles are identical (expect for the rotation around the circle)

Inheritance

Constructors

RectangleMirror({required Particle child, required double initialDistance, required int numberOfParticles})
RectangleMirror.builder({required ParticleBuilder particleBuilder, required double initialDistance, required int numberOfParticles})

Properties

hashCode int
The hash code for this object.
no setterinherited
initialDistance double
Position of the first particle on the rect
final
numberOfParticles int
final
particleBuilder ParticleBuilder
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

moveTo(Canvas canvas, Size size, int side, double x, double y, VoidCallback painter) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(Canvas canvas, Size size, double progress, int seed) → void
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited